@@ -9,7 +9,7 @@ no warnings;
 use subs qw(get_caller_info);
 use vars qw($VERSION $logger);
 
-$VERSION = '1.28_10';
+$VERSION = '1.18';
 
 =head1 NAME
 
@@ -39,9 +39,8 @@ __PACKAGE__->run( @ARGV ) unless caller;
 
 =over 4
 
-=item run( DISTS )
+=item run
 
-Takes a list of distributions and indexes them.
 
 =cut
 
@@ -102,7 +101,7 @@ Most of this needs to move out of run and into this method.
 Return a list of 3-element anonymous arrays that tell C<examine_dists>
 what to do. The elements of each anonymous array are:
 
-	1) the method to call (must be in indexing class or its parent classes)
+	1) the method to call (must be in indexing class or its parents)
 	2) a text description of the method
 	3) if a failure in that step should stop the exam: true or false
 
@@ -112,14 +111,12 @@ sub examine_dist_steps
 	{
 	my @methods = (
 		#    method                error message                  fatal
-		[ 'unpack_dist',        "Could not unpack distribution!",    1 ],
+		[ 'unpack_dist',        "Could not unpack distribtion!",     1 ],
 		[ 'find_dist_dir',      "Did not find distro directory!",    1 ],
 		[ 'get_file_list',      'Could not get file list',           1 ],
 		[ 'parse_meta_files',   "Could not parse META.yml!",         0 ],
 		[ 'find_modules',       "Could not find modules!",           1 ],
-		[ 'examine_modules',    "Could not process modules!",        0 ],
 		[ 'find_tests',         "Could not find tests!",             0 ],
-		[ 'examine_tests',      "Could not process tests!",          0 ],
 		);
 	}
 
@@ -129,14 +126,14 @@ sub examine_dist
 	my( $self ) = @_;
 
 	$self->set_run_info( 'examine_start_time', time );
-
+	
 	foreach my $tuple ( $self->examine_dist_steps )
 		{
 		my( $method, $error_msg, $die_on_error ) = @$tuple;
-		$logger->debug( "Running examine_dist step [$method]" );
-		
+
 		unless( $self->$method() )
 			{
+			$logger->error( $error_msg );
 			$self->set_run_info( 'fatal_error', $error_msg );
 
 			if( $die_on_error ) # only if failure is fatal
@@ -144,45 +141,41 @@ sub examine_dist
 				$logger->error( "Fatal error, stopping: $error_msg" );
 				return;
 				}
-			else
-				{
-				$logger->error( $error_msg );
-				}
 			}
 		}
 
+	{
+	my @file_info = ();
+	foreach my $file ( @{ $self->dist_info( 'modules' ) } )
+		{
+		$logger->debug( "Processing module $file" );
+		my $hash = $self->get_module_info( $file );
+		push @file_info, $hash;
+		}
+
+	$self->set_dist_info( 'module_info', [ @file_info ] );
+	}
+
+	{
+	my @file_info = ();
+	foreach my $file ( @{ $self->dist_info( 'tests' ) || [] } )
+		{
+		$logger->debug( "Processing test $file" );
+		my $hash = $self->get_test_info( $file );
+		push @file_info, $hash;
+		}
+
+	$self->set_dist_info( 'test_info', [ @file_info ] );
+	}
+
 	$self->set_run_info( 'examine_end_time', time );
-	$self->set_run_info( 'examine_time',
+	$self->set_run_info( 'examine_time', 
 		$self->run_info('examine_end_time') - $self->run_info('examine_start_time')
 		);
 
 	return 1;
 	}
 
-sub examine_modules
-	{
-	my( $self ) = @_;
-
-	my @file_info = map {
-		$logger->debug( "Processing module $_" );
-		$self->get_module_info( $_ );
-		} @{ $self->dist_info( 'modules' ) || [] };
-	
-	$self->set_dist_info( 'module_info', \@file_info );
-	}
-
-sub examine_tests
-	{
-	my( $self ) = @_;
-
-	my @file_info = map {
-		$logger->debug( "Processing test $_" );
-		$self->get_test_info( $_ );
-		} @{ $self->dist_info( 'tests' ) || [] };
-	
-	$self->set_dist_info( 'test_info', \@file_info );
-	}
-
 =item clear_run_info
 
 Clear anything recorded about the run.
@@ -380,57 +373,48 @@ sub unpack_dist
 
 	require Archive::Tar;
 	require Archive::Extract;
+	local $Archive::Extract::WARN = 0;
+	local $Archive::Tar::WARN = $Archive::Extract::WARN; # sent in patch for this rt.cpan.org #40472
 
-	local $Archive::Extract::DEBUG = $logger->is_debug;
-	local $Archive::Extract::WARN  = $logger->is_warn;
-	local $Archive::Tar::WARN      = $Archive::Extract::WARN; # sent in patch for this rt.cpan.org #40472
-	local $Archive::Extract::PREFER_BIN = defined $ENV{PREFER_BIN} ? $ENV{PREFER_BIN} : 0;
-	
-	foreach my $var ( qw( DEBUG WARN PREFER_BIN ) )
-		{
-		no strict 'refs';
-		
-		$logger->debug( qq|\$Archive::Extract::$var is |, ${"Archive::Extract::$var"} );	
-		}
-		
 	my $self = shift;
 	my $dist = $self->dist_info( 'dist_file' );
 	$logger->debug( "Unpacking dist $dist" );
 
 	return unless $self->get_unpack_dir;
 
-	my $extractor = eval { Archive::Extract->new( archive => $dist ) };
-	my $error = $@;
-	
+	my $extractor = eval {
+		Archive::Extract->new( archive => $dist );
+		};
+	local $Archive::Tar::WARN = 0;
+
 	if( $extractor->type eq 'gz' )
 		{
 		$logger->error( "Dist $dist claims to be a gz, so try .tgz instead" );
 
-		eval {
-			$extractor = Archive::Extract->new( archive => $dist, type => 'tgz' );
-			} || ($error = $@);
+		$extractor = eval {
+			Archive::Extract->new( archive => $dist, type => 'tgz' )
+			};
 		}
 
-	unless( ref $extractor )
+	unless( $extractor )
 		{
-		$logger->error( "Could create Archive::Extract object for $dist [$error]" );
+		$logger->error( "Could create Archive::Extract object for $dist [$@]" );
 		$self->set_dist_info( 'dist_archive_type', 'unknown' );
 		return;
 		}
 
 	$self->set_dist_info( 'dist_archive_type', $extractor->type );
 
-
-	my $rc = $extractor->extract( to => scalar $self->dist_info( 'unpack_dir' ) );
+	my $rc = $extractor->extract( to => $self->dist_info( 'unpack_dir' ) );
 	$logger->debug( "Archive::Extract returns [$rc] for $dist" );
 
-	# I should fail here, but Archive::Extract 0.26 on Windows fails
-	# even when it succeeds, so just log the error and keep going
 	unless( $rc or $^O =~ /Win32/ )
 		{
-		$self->set_dist_info( 'extraction_error', $extractor->error );
-		$logger->error( "Archive::Extract could not extract $dist" );
-		return;
+		$logger->error( "Archive::Extract could not extract $dist: " . $extractor->error(0) );
+		$self->set_dist_info( 'extraction_error', $extractor->error(0) );
+		# I should fail here, but Archive::Extract 0.26 on Windows fails 
+		# even when it succeeds, so just log the error and keep going
+		# return;
 		}
 
 	$self->set_dist_info( 'dist_extract_path', $extractor->extract_path );
@@ -644,25 +628,20 @@ Look in the lib/ directory for .pm files.
 
 =cut
 
-sub look_in_lib  { $_[0]->_look_in_dirs( 'lib' );  }
-sub look_in_blib { $_[0]->_look_in_dirs( 'blib' ); }
-				 
-sub _look_in_dirs
+sub look_in_lib
 	{
-	my( $self, @directories ) = @_;
-		
 	$logger->trace( sub { get_caller_info } );
 
 	require File::Find::Closures;
 	require File::Find;
 
 	my( $wanted, $reporter ) = File::Find::Closures::find_by_regex( qr/\.pm\z/ );
-	File::Find::find( $wanted, @directories );
+	File::Find::find( $wanted, 'lib' );
 
 	my @modules = $reporter->();
 	unless( @modules )
 		{
-		$logger->debug( "Did not find any modules in @directories" );
+		$logger->debug( "Did not find any modules in lib" );
 		return;
 		}
 
@@ -695,41 +674,6 @@ sub look_in_cwd
 	return 1;
 	}
 
-=item look_in_cwd_and_lib
-
-This is instantly deprecated. It's glue until I can figure out a
-better solution. 
-
-=cut
-
-sub look_in_cwd_and_lib
-	{
-	$logger->trace( sub { get_caller_info } );
-
-	$_[0]->_look_in_dirs( 'lib' );
-	
-	my $lib_modules = $_[0]->dist_info( 'modules' ) || [];
-
-	my @modules = glob( "*.pm" );
-
-	unless( @modules )
-		{
-		$logger->debug( "Did not find any modules in cwd" );
-		}
-
-	push @modules, @$lib_modules;
-	unless( @modules )
-		{
-		$logger->debug( "Did not find any modules in cwd and lib" );
-		return;
-		}
-	
-	$_[0]->set_dist_info( 'modules', [ @modules ] );
-
-	return 1;
-	}
-
-	
 =item look_in_meta_yml_provides
 
 As an almost-last-ditch effort, decide to beleive META.yml if it
@@ -772,7 +716,6 @@ sub look_in_meta_yml_provides
 
 	return 1;
 	}
-
 =item look_for_pm
 
 This is a last ditch effort to find modules by looking everywhere, starting
@@ -817,8 +760,8 @@ sub parse_meta_files
 
 	if( -e 'META.yml'  )
 		{
-		require YAML;
-		my $yaml = YAML::LoadFile( 'META.yml' );
+		require YAML::Syck;
+		my $yaml = YAML::Syck::LoadFile( 'META.yml' );
 		$_[0]->set_dist_info( 'META.yml', $yaml );
 		return $yaml;
 		}
@@ -841,7 +784,6 @@ sub find_module_techniques
 	{
 	my @methods = (
 		[ 'run_build_file', "Got from running build file"  ],
-		[ 'look_in_blib',   "Guessed from looking in blib/"  ],
 		[ 'look_in_lib',    "Guessed from looking in lib/" ],
 		[ 'look_in_cwd',    "Guessed from looking in cwd"  ],
 		[ 'look_in_meta_yml_provides',    "Guessed from looking in META.yml"  ],
@@ -851,8 +793,8 @@ sub find_module_techniques
 
 =item find_modules
 
-Find the module files. First, look in C<blib/>. If there are no files in
-C<blib/>, look in C<lib/>. If there are still none, look in the current
+Find the module files. First, look in C<blib/>. IF there are no files in
+C<blib/>, look in C<lib/>. IF there are still none, look in the current
 working directory.
 
 =cut
@@ -1050,7 +992,7 @@ to do. Each anonymous array holds:
 	0. method to call
 	1. description of technique
 
-The default list includes C<extract_module_namespaces>, C<exract_module_version>,
+The default list includes C<extract_module_namespaces>, C<exract_module_version>, 
 and C<extract_module_dependencies>. If you don't like that list, you can prune
 or expand it in a subclass.
 
@@ -1061,10 +1003,10 @@ sub get_module_info_tasks
 	(
 	[ 'extract_module_namespaces',   'Extract the namespaces a file declares' ],
 	[ 'extract_module_version',      'Extract the version of the module'      ],
-	[ 'extract_module_dependencies', 'Extract module dependencies'            ],
+	[ 'extract_module_dependencies', 'Extract module dependencies'            ],	
 	)
 	}
-
+	
 =item get_module_info( FILE )
 
 Collect meta informantion and package information about a module
@@ -1073,21 +1015,6 @@ the hash, including the version and package information.
 
 =cut
 
-sub get_modules_info
-	{
-        my $self = shift;
-	my @file_info = ();
-	foreach my $file ( @{ $self->dist_info( 'modules' ) } )
-		{
-		$logger->debug( "Processing module $file" );
-		my $hash = $self->get_module_info( $file );
-		push @file_info, $hash;
-		}
-
-	$self->set_dist_info( 'module_info', [ @file_info ] );
-	}
-
-
 sub get_module_info
 	{
 	$logger->trace( sub { get_caller_info } );
@@ -1099,14 +1026,14 @@ sub get_module_info
 	$logger->debug( "get_module_info called with [$file]\n" );
 
 	my @tasks = $self->get_module_info_tasks;
-
+	
 	foreach my $task ( @tasks )
 		{
 		my( $method, $description ) = @$task;
 		$logger->debug( "get_module_info calling [$method]\n" );
 
 		my $result = $self->$method( $file, $hash );
-
+		
 		unless( $result )
 			{
 			$self->set_run_info( 'error', "Problem with $method and $file" );
@@ -1115,57 +1042,22 @@ sub get_module_info
 
 	$hash;
 	}
-
+	
 sub extract_module_namespaces
 	{
 	my( $self, $file, $hash ) = @_;
-
+	
 	require Module::Extract::Namespaces;
-
-	my @packages = Module::Extract::Namespaces->from_file( $file );
+	
+	my @packages             = Module::Extract::Namespaces->from_file( $file );
 
 	$logger->warn( "Didn't find any packages in $file" ) unless @packages;
-
-	$hash->{packages} = [ @packages ];
-
-	$hash->{module_name_from_file_guess} = $self->get_package_name_from_filename( $file );
-
-	$hash->{primary_package} = $self->guess_primary_package( $hash->{packages}, $file );
-
+	
+	$hash->{packages}        = [ @packages ];
+	$hash->{primary_package} = $packages[0];
+	
 	1;
 	}
-
-sub get_package_name_from_filename
-	{
-	my( $self, $file ) = @_;
-
-	# some people do odd things in their distributions, like fork
-	# modules. I'll try to guess the primary package by seeing if
-	# there is a package that matches the file name.
-	#
-	# See, for instance, Module::Info and it's B::BUtil fork.
-	( my $module = $file ) =~ s|.*(?:blib\b.)?lib\b.||g;
-	$module =~ s/\.pm\z//;
-	$module =~ s|[\\/]|::|g;
-	
-	$module;
-	}
-	
-sub guess_primary_package
-	{
-	my( $self, $packages, $file ) = @_;
-
-	# ignore packages that start with an underscore
-	@$packages = grep { ! /\b_/ } @$packages;
-	
-	my $module = $self->get_package_name_from_filename( $file );
-	
-	my @matches = grep { $_ eq $module } @$packages;
-
-	my $primary_package = $matches[0] || $packages->[0];
-
-	return $primary_package;	
-	}
 	
 sub extract_module_version
 	{
@@ -1174,25 +1066,25 @@ sub extract_module_version
 	require Module::Extract::VERSION;
 
 	my @keys = qw( sigil identifier value filename line_number );
-
+	
 	my @version_info = eval {
 		local $SIG{__WARN__} = sub { die @_ };
 		my @v = Module::Extract::VERSION->parse_version_safely( $file );
 		};
-
+	
 	# I don't have a better way to know if nothing was found. I need
 	# to fix that in Module::Extract::VERSION
 	my $defined_count = grep defined, @version_info;
-
-	my %v = ! $defined_count ? () :
+	
+	my %v = ! $defined_count ? () : 
 		map  { $keys[$_] => $version_info[$_] } 0 .. $#keys;
-
+	
 	$v{error} = $@ if $@;
-
+	
 	$hash->{version_info} = \%v;
-
+	
 	return 0 if $@;
-
+	
 	1;
 	}
 
@@ -1211,10 +1103,10 @@ sub extract_module_dependencies
 		}
 
 	$hash->{uses} = [ @uses ];
-
-	1;
+	
+	1;	
 	}
-
+	
 =item get_test_info( FILE )
 
 Collect meta informantion and package information about a test
@@ -1376,9 +1268,9 @@ sub get_caller_info
 
 sub get_md5
 	{
-	require Digest::MD5;
+	require MD5;
 
-	my $context = Digest::MD5->new;
+	my $context = MD5->new;
 	$context->add( $_[1] );
 	$context->hexdigest;
 	}
@@ -1420,7 +1312,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008-2009, brian d foy, All Rights Reserved.
+Copyright (c) 2008, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
